require 'helper'

module Monark
  class DSLTest < MiniTest::Unit::TestCase

    test 'set_version should set the version on the context' do
      dsl.set_version 42
      assert_equal 42, context.version
    end

    test 'add should instantiate a migration and add it to the context' do
      dsl.add "foo"
      assert_equal Migration, context.migrations.first.class
    end

    test 'add should not add a migration if the group differs from the env' do
      dsl.add "foo", :group => :production
      assert_equal [], context.migrations
    end

    test 'add should add a migration if the groups is the env' do
      dsl.add "foo", :group => :development
      assert_equal Migration, context.migrations.first.class
    end

    test 'add should not add a migration if the groups do not include the env' do
      dsl.add "foo", :groups => [:production, :whatever]
      assert_equal [], context.migrations
    end

    test 'add should add a migration if the groups include the env' do
      dsl.add "foo", :groups => [:production, :development]
      assert_equal Migration, context.migrations.first.class
    end

    test 'group should yield if the group is the env' do
      dsl.group(:development) {assert true}
    end

    test 'group should yield if the group differs from the env' do
      dsl.group(:production) {flunk}
    end

    test 'groups should not yield the groups do not include the env' do
      dsl.groups(:production, :test) {flunk}
    end

    test 'groups should yield the groups include the env' do
      dsl.groups(:production, :development) {assert true}
    end

    private

    def dsl
      @dsl ||= DSL.new(context)
    end

    def context
      @context ||= Context.new(File.expand_path('../fixtures', __FILE__))
    end
  end
end