require 'helper'

module Monark

  def teardown
    Object.send(:remove_const, :Rails) rescue NameError
    ENV.delete 'RACK_ENV'
    ENV.delete 'MONARK_ENV'
  end

  test 'should have a version' do
    assert_not_nil Monark::VERSION
  end

  test "should load env from ENV['MONARK_ENV'] if present" do
    ENV['MONARK_ENV'] = 'production'
    assert_equal 'production', Monark.env
  end

  test 'should load env from Rails.env if present' do
    ::Rails = OpenStruct.new(:env => 'production')
    assert_equal 'production', Monark.env
  end

  test "should load env from ENV['RACK_ENV'] if present" do
    ENV['RACK_ENV'] = 'production'
    assert_equal 'production', Monark.env
  end

  test 'env should default to development' do
    assert_equal 'development', Monark.env
  end

  test 'should favor MONARK_ENV over Rails env' do
    ::Rails = OpenStruct.new(:env => "test")
    ENV['MONARK_ENV'] = 'production'
    assert_equal 'production', Monark.env
    ENV.delete 'MONARK_ENV'
    assert_equal 'test', Monark.env
  end

  test 'should favor Rails env over RACK_ENV' do
    ::Rails = OpenStruct.new(:env => "test")
    ENV['RACK_ENV'] = 'production'
    assert_equal 'test', Monark.env
    Object.send :remove_const, :Rails
    assert_equal 'production', Monark.env
  end
end